@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: garmin.tcl
-#  Last change:  16 July 2001
+#  Last change:  4 February 2002
 #
 
  # implemented using
@@ -1224,7 +1224,7 @@ proc UnPackData {data types} {
     # convert from list of bytes (as TCL characters) to list of elements
     #  conforming to the types in the list $types
     # delete leading and trailing spaces of strings and char arrays
-    global PacketDataRest PDTSIZE
+    global PacketDataRest PDTSIZE tcl_platform
 
     set vals ""
     foreach t $types {
@@ -1255,12 +1255,32 @@ proc UnPackData {data types} {
 		binary scan [join [lrange $data 0 3] ""] "i" x
 	    }
 	    float {
+		# this only works with machines following the
+		#  IEEE standard floating point representation
 		set n 4
-		binary scan [join [lrange $data 0 3] ""] "f" x
+		if { "$tcl_platform(byteOrder)" == "littleEndian" } {
+		    binary scan [join [lrange $data 0 3] ""] "f" x
+		} else {
+		    set id ""
+		    foreach k "3 2 1 0" {
+			lappend id [lindex $data $k]
+		    }
+		    binary scan [join $id ""] "f" x
+		}
 	    }
 	    double {
+		# this only works with machines following the
+		#  IEEE standard floating point representation
 		set n 8
-		binary scan [join [lrange $data 0 7] ""] "d" x
+		if { "$tcl_platform(byteOrder)" == "littleEndian" } {
+		    binary scan [join [lrange $data 0 7] ""] "d" x
+		} else {
+		    set id ""
+		    foreach k "7 6 5 4 3 2 1 0" {
+			lappend id [lindex $data $k]
+		    }
+		    binary scan [join $id ""] "d" x
+		}
 	    }
 	    string {
 		set x "" ; set n 0
@@ -1370,6 +1390,7 @@ proc PackData {tvals} {
 proc DataToStr {types vals} {
     # convert from list of elements conforming to the types in $types to
     #  a TCL string
+    global tcl_platform
 
     set data ""
     foreach t $types v $vals {
@@ -1390,10 +1411,30 @@ proc DataToStr {types vals} {
 		append data [binary format "i" $v]
 	    }
 	    float {
-		append data [binary format "f" $v]
+		# this only works with machines following the
+		#  IEEE standard floating point representation
+		set s [binary format "f" $v]
+		if { "$tcl_platform(byteOrder)" != "littleEndian" } {
+		    set l [split "$s" ""]
+		    set s ""
+		    foreach k "3 2 1 0" {
+			append s [lindex $l $k]
+		    }
+		}
+		append data $s
 	    }
 	    double {
-		append data [binary format "d" $v]
+		# this only works with machines following the
+		#  IEEE standard floating point representation
+		set s [binary format "d" $v]
+		if { "$tcl_platform(byteOrder)" != "littleEndian" } {
+		    set l [split "$s" ""]
+		    set s ""
+		    foreach k "7 6 5 4 3 2 1 0" {
+			append s [lindex $l $k]
+		    }
+		}
+		append data $s
 	    }
 	    string {
 		append data [binary format "a*x" $v]
@@ -1455,6 +1496,17 @@ proc DataToStr {types vals} {
     return $data
 }
 
+proc BadFloats {} {
+    # check whether conversions of bytes to float are working correctly
+    #  in this machine
+    global MESS
+
+    if { abs([UnPackData "A B C D" float]-781.035217285) > 1e-3 } {
+	return [expr ! [GMConfirm $MESS(badfloats)]]
+    }
+    return 0
+}
+
 ##### upper level
 
 proc EndOutProt {pid} {
@@ -1584,7 +1636,7 @@ proc ConvWPData {data pid} {
 		Alt {
 		    switch $pid {
 			D108 {
-			    if { $v > 9.9e24 } { set v "" }
+			    if { $v > 1e10 } { set v "" }
 			}
 			D150 -  D151 -  D152 -  D154 -  D155 {
 			    # this depends on what HiddenGet does!
@@ -1774,10 +1826,10 @@ proc ConvTPData {data pid} {
 	D301 {
 	    set p [lindex $data 0]
 	    set d [lindex $data 1]
-	    if { [set alt [lindex $data 2]] < 9.9e24 } {
+	    if { [set alt [lindex $data 2]] < 1e10 } {
 		lappend fs alt ; lappend vs $alt
 	    }
-	    if { [set dep [lindex $data 3]] < 9.9e24 } {
+	    if { [set dep [lindex $data 3]] < 1e10 } {
 		lappend fs depth ; lappend vs $dep
 	    }
 	    set new [lindex $data 4]
@@ -2455,6 +2507,7 @@ proc GPSConnection {args} {
 	return
     }
     if { $NoGarmin } {
+	if { [BadFloats] } { return }
 	if { [OpenSerialFailed 9600] } {
 	    eval [lindex $args 1]
 	    return
