@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: gendials.c
-#  Last change:  4 September 2001
+#  Last change:  5 December 2001
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -74,7 +74,7 @@ proc GMConfirm {mess} {
     label .mess.fr.text -text "$mess"
     frame .mess.fr.bs
     button .mess.fr.bs.ok -text Ok -command "set Temp2 1 ; set wait2 0"
-    button .mess.fr.bs.cancel -text $TXT(cancel) \
+    button .mess.fr.bs.cancel -text $TXT(no) \
 	    -command "set Temp2 0 ; set wait2 0"
     pack .mess.fr.bs.ok .mess.fr.bs.cancel -side left -pady 5
     pack .mess.fr.title .mess.fr.text .mess.fr.bs -side top -pady 5
