@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langengl.tcl
-#  Last change:  20 November 2001
+#  Last change:  1 February 2002
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #
@@ -66,7 +66,6 @@ array set MESS {
     undefWP   "Route %s has undefined WP(s); not saved/exported"
     bigRT   "Route %s > max number; not exported"
     unkndatum   "Unknown datum"
-    nogrids   "Grids not implemented"
     badcommdWP   "Bad command when loading WPs; line"
     notabsWP   "Bad WP definition; no tabs, line"
     undefWP   "Reference to unknown WP: %s; line %d"
@@ -233,6 +232,7 @@ array set MESS {
     badinvproj "Approximation error when inverting %s projection"
     negdlatlong "Lat/long range cannot be negative!"
     allundef "There are no definitions for the WPs in the GR"
+    badfloats "Floating-point conversions not working correctly; are you sure you want to connect?"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg m stage label"
@@ -443,6 +443,7 @@ array set TXT {
     YYYYMMDD   YYYYMMDD
     MMDDYYYY   MMDDYYYY
     DDMMMYYYY   DDMMMYYYY
+    YYYY-MM-DD  YYYY-MM-DD
     mainwd   "Main window"
     distazim   "Dist and bearing"
     nearestWPs   "Nearest WPs"
@@ -715,6 +716,7 @@ array set TXT {
     longF "Long false origin"
     gkklong0 "Long of centre"
     kkjplong0 "Long of centre"
+    twglong0 "Long of centre"
     k0 "Scale factor"
     PRJUTM "UTM/UPS"
     PRJTM "Transverse Mercator"
@@ -732,6 +734,8 @@ array set TXT {
     PRJMerc2 "Mercator 2"
     PRJCS "Cassini-Soldner"
     PRJAPOLY "American Polyconic"
+    PRJStereogr Stereographic
+    PRJTWG "Taiwan Grid"
     dontaskagain "Stop asking"
     rename "Use new name"
     oname "Original name"
@@ -834,6 +838,7 @@ array set TXT {
     collcntr "Collecting centres..."
     compclstr "Computing clusters..."
     crtgclstrgrs "Creating groups..."
+    chgdatum "Change datum..."
 }
 
     # the following definitions must be coherent with $TXT
