@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 #      along with this program.
 #
 #  File: langit.tcl
-#  Last change:  21 November 2001
+#  Last change:  1 February 2002
 # Italian language file by Alessandro Palmas (alpalmas@tin.it)
 #  Last change by him: Sat Jul 22 17:06:06 CEST 2000
 #  ALPHA VERSION
-#  last input from him inserted: 21 November 2001
+#  last input from him inserted: 31 January 2002
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -68,7 +68,6 @@ array set MESS {
     undefWP   "La rotta %s ha WP non definiti; non salvata/esportata"
     bigRT   "Rotta %s > num. max; non esportata"
     unkndatum   "Datum sconosciuto"
-    nogrids   "Griglia non implementata"
     badcommdWP   "Comando scorretto caricando i WPs; linea"
     notabsWP   "Definizione WP scorretta; no tabs, linea"
     undefWP   "Riferimento a WP ignoto: %s; linea %d"
@@ -236,6 +235,8 @@ array set MESS {
     badinvproj "Errore di approssimazione invertendo la proiezione %s"
     negdlatlong "L'escursione lat/long non deve essere negativa"
     allundef "I WP non sono definiti nel GR"
+    badfloats "Le conversioni in virgola mobile non funzionano correttamente; 
+siete sicuri di volervi connettere?"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} deg m stage label"
@@ -664,6 +665,7 @@ array set TXT {
     long0 "Long del centro"
     gkklong0 "Long del centro"
     kkjplong0 "Long del centro"
+    twglong0 "Long del centro"
     k0 "Fattore di Scala a CM"
     PRJTM "Transversa di Mercatore"
     rename "Usare nuovo nome"
@@ -784,6 +786,9 @@ array set TXT {
     collcntr "Ricerco centri..."
     compclstr "Calcolo dintorni..."
     crtgclstrgrs "Creo gruppi..."
+    PRJStereogr "Stereografica"
+    PRJTWG "Griglia di Taiwan"
+    chgdatum "Cambia datum"
 }
 
     # the following definitions must be coherent with $TXT
