@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: langport.tcl
-#  Last change:  14 November 2001
+#  Last change:  1 February 2002
 #
 
 # file langengl.tcl is consulted first; no need for duplicating entries here
@@ -66,7 +66,6 @@ array set MESS {
     undefWP   "Rota %s tem pontos no definidos; no guardada/exportada"
     bigRT   "Rota %s > mximo; no exportada"
     unkndatum   "Datum desconhecido"
-    nogrids   "Grelhas no implementadas"
     badcommdWP   "Comando errado ao ler pontos; linha"
     notabsWP   "Ponto mal definido (sem tabulaes); linha"
     undefWP   "Referncia a ponto desconhecido: %s; linha %d"
@@ -233,6 +232,7 @@ array set MESS {
     badinvproj "Erro de aproximao ao inverter a projeco %s"
     negdlatlong "Diferena em lat/long no pode ser negativa!"
     allundef "Nenhum dos PTs do GR est definido"
+    badfloats "H erros nas converses de nmeros decimais; ligar mesmo assim?"
 }
 
 set TXT(RTcompflds) "# PT {$DTUNIT} grau m etapa etiq"
@@ -440,6 +440,7 @@ array set TXT {
     YYYYMMDD   AAAAMMDD
     MMDDYYYY   MMDDAAAA
     DDMMMYYYY   DDMMMAAAA
+    YYYY-MM-DD  AAAA-MM-DD
     mainwd   "Janela principal"
     distazim   "Dist e azimute"
     nearestWPs   "PTs prximos"
@@ -698,6 +699,7 @@ array set TXT {
     longF "Long falsa origem"
     gkklong0 "Long central"
     kkjplong0 "Long central"
+    twglong0 "Long central"
     k0 "Factor de escala"
     PRJUTM "UTM/UPS"
     PRJTM "Transversa de Mercator"
@@ -712,6 +714,8 @@ array set TXT {
     PRJKKJY "Grelha Finlandesa Unif"
     PRJSEG "Grelha Sueca"
     PRJAPOLY "Policnica Americana"
+    PRJStereogr "Estereogrfica"
+    PRJTWG "Grelha de Taiwan"
     dontaskagain "Deixar de confirmar"
     rename "Usar nome diferente"
     oname "Nome original"
@@ -794,6 +798,7 @@ array set TXT {
     collcntr "A determinar centros..."
     compclstr "A agrupar vizinhos..."
     crtgclstrgrs "A criar grupos..."
+    chgdatum "Mudar datum..."
 }
 
     # the following definitions must be coherent with $TXT
