@@ -1,7 +1,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-#  Copyright (c) 2001 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
+#  Copyright (c) 2002 Miguel Filgueiras (mig@ncc.up.pt) / Universidade do Porto
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 #      along with this program.
 #
 #  File: map.tcl
-#  Last change:  14 November 2001
+#  Last change:  6 January 2002
 #
 # Includes contributions by Brian Baulch (baulchb@onthenet.com.au)
 #  marked "BSB contribution"
@@ -142,7 +142,8 @@ proc MarkMapPoint {x y} {
 		    if { "$os" == "" || [OverBackImage $os] } {
 			if { [winfo exists $EdWindow(WP)] } { bell ; return }
 			set p [MapToPosn $xx $yy $MapPFormat]
-			if { "[PosType $MapPFormat]" == "grid" && \
+			set ptype [PosType $MapPFormat]
+			if { ("$ptype" == "grid" || "$ptype" == "nzgrid") && \
 				"[lindex $p 2]" == "--" } {
 			    set pfmt UTM/UPS
 			    set p [MapToPosn $xx $yy UTM/UPS]
@@ -716,16 +717,24 @@ proc SetMapCoords {xm ym} {
 	    set YCoord [expr round([lindex $p 3])]
 	    set MapZone [format %d%s [lindex $p 0] [lindex $p 1]]
 	}
+	MH {
+	    set p [eval $MapProjInvertProc MPData $pt DDD]
+	    set p [DegreesToMHLoc [lindex $p 0] [lindex $p 1] $Datum]
+	    set XCoord [lindex $p 1] ; set YCoord "" ; set MapZone ""
+	}
 	default {
+	    # assumed to be a grid with/out zones
 	    set p [eval $MapProjInvertProc MPData $pt DDD]
 	    if { $ZGRID($MapPFormat) } {
 		set p [DegreesTo$MapPFormat [lindex $p 0] [lindex $p 1] $Datum]
+		set MapZone [lindex $p 0]
+		set XCoord [lindex $p 1] ; set YCoord [lindex $p 2]
 	    } else {
 		set p [DegreesToNZGrid $MapPFormat \
 			[lindex $p 0] [lindex $p 1] $Datum]
+		set MapZone ""
+		set XCoord [lindex $p 0] ; set YCoord [lindex $p 1]
 	    }
-	    set XCoord [lindex $p 1] ; set YCoord [lindex $p 2]
-	    set MapZone [lindex $p 0]
 	}
     }
     return
